@@ -5,29 +5,27 @@
 #' @param target the target layer from which to remove portions. One of:
 #' \itemize{
 #'  \item \code{geo_json} or \code{character} points, lines, or polygons;
-#'  \item \code{geo_list} points, lines, or polygons;
 #'  \item \code{SpatialPolygons}, \code{SpatialLines}, \code{SpatialPoints};
 #'  \item \code{sf} or \code{sfc} points, lines, or polygons object
 #'  }
 #' @param clip the clipping layer (polygon). One of:
 #' \itemize{
 #'  \item \code{geo_json} or \code{character} polygons;
-#'  \item \code{geo_list} polygons;
 #'  \item \code{SpatialPolygons*};
 #'  \item \code{sf} or \code{sfc} polygons object
 #' }
 #' @param bbox supply a bounding box instead of a clipping layer to extract from
 #'   the target layer. Supply as a numeric vector: \code{c(minX, minY, maxX, maxY)}.
 #' @param remove_slivers Remove tiny sliver polygons created by clipping. (Default \code{FALSE})
-#' @inheritParams apply_mapshaper_commands
+#' @inheritDotParams apply_mapshaper_commands force_FC sys sys_mem quiet
 #'
 #' @return clipped target in the same class as the input target
 #'
 #' @examples
 #'
 #' if (rmapshaper:::check_v8_major_version() >= 6L) {
-#'   library(geojsonio, quietly = TRUE)
-#'   library(sp)
+#'   library(geojsonsf, quietly = TRUE)
+#'   library(sf)
 #'
 #'   poly <- structure("{\"type\":\"FeatureCollection\",
 #'     \"features\":[{\"type\":\"Feature\",\"properties\":{},
@@ -39,8 +37,8 @@
 #'     [52.0329,-49.5677],[50.1747,-52.1814],[49.0098,-52.3641],
 #'     [52.7068,-45.7639],[43.2278,-47.1908],[48.4755,-45.1388],
 #'     [50.327,-43.5207],[48.0804,-41.2784],[49.6307,-40.6159],
-#'     [52.8658,-44.7219]]]}}]}", class = c("json", "geo_json"))
-#'   poly <- geojson_sp(poly)
+#'     [52.8658,-44.7219]]]}}]}", class = c("geojson", "json"))
+#'   poly <- geojson_sf(poly)
 #'   plot(poly)
 #'
 #'   clip_poly <- structure('{
@@ -58,8 +56,8 @@
 #'   ]
 #'   ]
 #'   }
-#'   }', class = c("json", "geo_json"))
-#'   clip_poly <- geojson_sp(clip_poly)
+#'   }', class = c("geojson", "json"))
+#'   clip_poly <- geojson_sf(clip_poly)
 #'   plot(clip_poly)
 #'
 #'   out <- ms_clip(poly, clip_poly)
@@ -67,70 +65,60 @@
 #' }
 #'
 #' @export
-ms_clip <- function(target, clip = NULL, bbox = NULL, remove_slivers = FALSE,
-                    force_FC = TRUE, sys = FALSE, sys_mem = 8) {
-  if (!is.logical(force_FC)) stop("force_FC must be TRUE or FALSE")
+ms_clip <- function(target, clip = NULL, bbox = NULL, remove_slivers = FALSE, ...) {
   stop_for_old_v8()
   UseMethod("ms_clip")
 }
 
 #' @export
 ms_clip.character <- function(target, clip = NULL, bbox = NULL,
-                              remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                              remove_slivers = FALSE, ...) {
   target <- check_character_input(target)
 
   clip_erase_json(target = target, overlay_layer = clip, type = "clip",
-                  remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                  remove_slivers = remove_slivers, bbox = bbox, ...)
 
 }
 
 #' @export
-ms_clip.geo_json <- function(target, clip = NULL, bbox = NULL, remove_slivers = FALSE,
-                             force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+ms_clip.json <- function(target, clip = NULL, bbox = NULL, remove_slivers = FALSE, ...) {
   clip_erase_json(target = target, overlay_layer = clip, type = "clip",
-                  remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
-}
-
-#' @export
-ms_clip.geo_list <- function(target, clip = NULL, bbox = NULL, remove_slivers = FALSE,
-                             force_FC = TRUE, sys = FALSE, sys_mem = 8) {
-  clip_erase_geo_list(target = target, overlay_layer = clip, type = "clip",
-                      remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                  remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' @export
 ms_clip.SpatialPolygons <- function(target, clip = NULL, bbox = NULL,
-                                    remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                    remove_slivers = FALSE, ...) {
   clip_erase_sp(target = target, overlay_layer = clip, type = "clip",
-                remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' @export
 ms_clip.SpatialLines <- function(target, clip = NULL, bbox = NULL,
-                                 remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                 remove_slivers = FALSE, ...) {
   clip_erase_sp(target = target, overlay_layer = clip, type = "clip",
-                remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' @export
 ms_clip.SpatialPoints <- function(target, clip = NULL, bbox = NULL,
-                                  remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                  remove_slivers = FALSE, ...) {
   clip_erase_sp(target = target, overlay_layer = clip, type = "clip",
-                remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' @export
 ms_clip.sf <- function(target, clip = NULL, bbox = NULL,
-                       remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                       remove_slivers = FALSE, ...) {
   clip_erase_sf(target = target, overlay_layer = clip, type = "clip",
-                remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' @export
 ms_clip.sfc <- function(target, clip = NULL, bbox = NULL,
-                       remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                       remove_slivers = FALSE, ...) {
   clip_erase_sf(target = target, overlay_layer = clip, type = "clip",
-                remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' Remove features or portions of features that fall inside a specified area
@@ -140,25 +128,23 @@ ms_clip.sfc <- function(target, clip = NULL, bbox = NULL,
 #' @param target the target layer from which to remove portions. One of:
 #' \itemize{
 #'  \item \code{geo_json} or \code{character} points, lines, or polygons;
-#'  \item \code{geo_list} points, lines, or polygons;
 #'  \item \code{SpatialPolygons}, \code{SpatialLines}, \code{SpatialPoints}
 #'  }
 #' @param erase the erase layer (polygon). One of:
 #' \itemize{
 #'  \item \code{geo_json} or \code{character} polygons;
-#'  \item \code{geo_list} polygons;
 #'  \item \code{SpatialPolygons*}
 #' }
 #' @param bbox supply a bounding box instead of an erasing layer to remove from
 #'   the target layer. Supply as a numeric vector: \code{c(minX, minY, maxX, maxY)}.
 #' @param remove_slivers Remove tiny sliver polygons created by erasing. (Default \code{FALSE})
-#' @inheritParams apply_mapshaper_commands
+#' @inheritDotParams apply_mapshaper_commands force_FC sys sys_mem quiet
 #'
 #' @return erased target in the same format as the input target
 #' @examples
 #' if (rmapshaper:::check_v8_major_version() >= 6L) {
-#'   library(geojsonio, quietly = TRUE)
-#'   library(sp)
+#'   library(geojsonsf, quietly = TRUE)
+#'   library(sf)
 #'
 #'   points <- structure("{\"type\":\"FeatureCollection\",
 #'     \"features\":[{\"type\":\"Feature\",\"properties\":{},
@@ -175,8 +161,8 @@ ms_clip.sfc <- function(target, clip = NULL, bbox = NULL,
 #'     {\"type\":\"Point\",\"coordinates\":[61.0835,-40.7529]}},
 #'     {\"type\":\"Feature\",\"properties\":{},\"geometry\":
 #'     {\"type\":\"Point\",\"coordinates\":[58.0202,-43.634]}}]}",
-#'     class = c("json", "geo_json"))
-#'   points <- geojson_sp(points)
+#'     class = c("geojson", "json"))
+#'   points <- geojson_sf(points)
 #'   plot(points)
 #'
 #'   erase_poly <- structure('{
@@ -194,8 +180,8 @@ ms_clip.sfc <- function(target, clip = NULL, bbox = NULL,
 #'   ]
 #'   ]
 #'   }
-#'   }', class = c("json", "geo_json"))
-#'   erase_poly <- geojson_sp(erase_poly)
+#'   }', class = c("geojson", "json"))
+#'   erase_poly <- geojson_sf(erase_poly)
 #'
 #'   out <- ms_erase(points, erase_poly)
 #'   plot(out, add = TRUE)
@@ -203,73 +189,67 @@ ms_clip.sfc <- function(target, clip = NULL, bbox = NULL,
 #'
 #'@export
 ms_erase <- function(target, erase = NULL, bbox = NULL,
-                     remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
-  if (!is.logical(force_FC)) stop("force_FC must be TRUE or FALSE")
+                     remove_slivers = FALSE, ...) {
   stop_for_old_v8()
   UseMethod("ms_erase")
 }
 
 #' @export
 ms_erase.character <- function(target, erase = NULL, bbox = NULL,
-                               remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                               remove_slivers = FALSE, ...) {
   target <- check_character_input(target)
 
   clip_erase_json(target = target, overlay_layer = erase, type = "erase",
-                  remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                  remove_slivers = remove_slivers, bbox = bbox, ...)
 
 }
 
 #' @export
-ms_erase.geo_json <- function(target, erase = NULL, bbox = NULL,
-                              remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+ms_erase.json <- function(target, erase = NULL, bbox = NULL,
+                              remove_slivers = FALSE, ...) {
   clip_erase_json(target = target, overlay_layer = erase, type = "erase",
-                  remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
-}
-
-#' @export
-ms_erase.geo_list <- function(target, erase = NULL, bbox = NULL,
-                              remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
-  clip_erase_geo_list(target = target, overlay_layer = erase, type = "erase",
-                      remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                  remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' @export
 ms_erase.SpatialPolygons <- function(target, erase = NULL, bbox = NULL,
-                                     remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                     remove_slivers = FALSE, ...) {
   clip_erase_sp(target = target, overlay_layer = erase, type = "erase",
-                remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' @export
 ms_erase.SpatialLines <- function(target, erase = NULL, bbox = NULL,
-                                  remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                  remove_slivers = FALSE, ...) {
   clip_erase_sp(target = target, overlay_layer = erase, type = "erase",
-                remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' @export
 ms_erase.SpatialPoints <- function(target, erase = NULL, bbox = NULL,
-                                   remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                   remove_slivers = FALSE, ...) {
   clip_erase_sp(target = target, overlay_layer = erase, type = "erase",
-                remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' @export
 ms_erase.sf <- function(target, erase = NULL, bbox = NULL,
-                       remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                       remove_slivers = FALSE, ...) {
   clip_erase_sf(target = target, overlay_layer = erase, type = "erase",
-                remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 #' @export
 ms_erase.sfc <- function(target, erase = NULL, bbox = NULL,
-                        remove_slivers = FALSE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                        remove_slivers = FALSE, ...) {
   clip_erase_sf(target = target, overlay_layer = erase, type = "erase",
-                remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                remove_slivers = remove_slivers, bbox = bbox, ...)
 }
 
 clip_erase_json <- function(target, overlay_layer, bbox, remove_slivers, type,
-                            force_FC, sys, sys_mem) {
+                            force_FC = TRUE, sys = FALSE,
+                            sys_mem = getOption("mapshaper.sys_mem", default = 8),
+                            quiet = getOption("mapshaper.sys_quiet", default = FALSE)) {
 
   check_overlay_bbox(overlay_layer = overlay_layer, bbox = bbox, type = type)
 
@@ -278,39 +258,23 @@ clip_erase_json <- function(target, overlay_layer, bbox, remove_slivers, type,
   }
 
   mapshaper_clip_erase(target_layer = target, overlay_layer = overlay_layer, type = type,
-                       remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+                       remove_slivers = remove_slivers, bbox = bbox,
+                       force_FC = force_FC, sys = sys, sys_mem = sys_mem, quiet = quiet)
 }
 
-clip_erase_geo_list <- function(target, overlay_layer, bbox, type,
-                                remove_slivers, force_FC, sys, sys_mem) {
+clip_erase_sp <- function(target, overlay_layer, bbox, type, remove_slivers,
+                          force_FC = TRUE, sys = FALSE,
+                          sys_mem = getOption("mapshaper.sys_mem", default = 8),
+                          quiet = getOption("mapshaper.sys_quiet", default = FALSE)) {
 
   check_overlay_bbox(overlay_layer = overlay_layer, bbox = bbox, type = type)
 
-  if (is.null(bbox)) {
-    if (!is(overlay_layer, "geo_list")) stop("both target and ", type, " must be class geo_list")
-    overlay_layer <- geo_list_to_json(overlay_layer)
-  }
-  target <- geo_list_to_json(target)
-  ret <- clip_erase_json(target = target, overlay_layer = overlay_layer, type = type,
-                         remove_slivers = remove_slivers, bbox = bbox, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
-  geojsonio::geojson_list(ret)
-}
-
-clip_erase_sp <- function(target, overlay_layer, bbox, type, remove_slivers, force_FC, sys, sys_mem) {
-
-  check_overlay_bbox(overlay_layer = overlay_layer, bbox = bbox, type = type)
-
-  target_proj <- slot(target, "proj4string")
+  target_proj <- methods::slot(target, "proj4string")
 
   if (is.null(bbox)) {
     if (!is(overlay_layer, "SpatialPolygons")) stop(type, " must be of class SpatialPolygons or SpatialPolygonsDataFrame")
     if (!sp::identicalCRS(target, overlay_layer)) {
-      warning("target and ", type, " do not have identical CRS. Transforming ",
-              type, " to target CRS")
-      if (!requireNamespace("rgdal")) {
-        stop("You need the rgdal package to use transform non-equivalent projections.")
-      }
-      overlay_layer <- sp::spTransform(overlay_layer, target_proj)
+      stop("target and ", type, " do not have identical CRS.", call. = FALSE)
     }
     overlay_geojson <- sp_to_GeoJSON(overlay_layer, file = sys)
   }
@@ -332,7 +296,10 @@ clip_erase_sp <- function(target, overlay_layer, bbox, type, remove_slivers, for
   ret
 }
 
-clip_erase_sf <- function(target, overlay_layer, bbox, type, remove_slivers, force_FC, sys, sys_mem) {
+clip_erase_sf <- function(target, overlay_layer, bbox, type, remove_slivers,
+                          force_FC = TRUE, sys = FALSE,
+                          sys_mem = getOption("mapshaper.sys_mem", default = 8),
+                          quiet = getOption("mapshaper.sys_quiet", default = FALSE)) {
 
   check_overlay_bbox(overlay_layer = overlay_layer, bbox = bbox, type = type)
 
@@ -348,10 +315,8 @@ clip_erase_sf <- function(target, overlay_layer, bbox, type, remove_slivers, for
         !all(sf::st_is(overlay_layer, c("POLYGON", "MULTIPOLYGON")))) {
       stop(type, " must be an sf or sfc object with POLYGON or MULTIPLOYGON geometry")
     }
-    if (sf::st_crs(target) != sf::st_crs(overlay_layer)) {
-      warning("target and ", type, " do not have identical CRS. Transforming ",
-              type, " to target CRS")
-      overlay_layer <- sf::st_transform(overlay_layer, target_proj)
+    if (target_proj != sf::st_crs(overlay_layer)) {
+      stop("target and ", type, " do not have identical CRS.", call. = FALSE)
     }
     overlay_geojson <- sf_to_GeoJSON(overlay_layer, file = sys)
   }
@@ -394,7 +359,9 @@ check_overlay_bbox <- function(overlay_layer, bbox, type) {
 }
 
 mapshaper_clip_erase <- function(target_layer, overlay_layer, bbox, type,
-                                 remove_slivers, force_FC, sys, sys_mem) {
+                                 remove_slivers, force_FC = TRUE, sys = FALSE,
+                                 sys_mem = getOption("mapshaper.sys_mem", default = 8),
+                                 quiet = getOption("mapshaper.sys_quiet", default = FALSE)) {
 
 
   remove_slivers <- ifelse(remove_slivers, "remove-slivers", "")
@@ -402,13 +369,13 @@ mapshaper_clip_erase <- function(target_layer, overlay_layer, bbox, type,
   if (!is.null(bbox)) {
     cmd <- paste0("-", type, " bbox=",paste0(bbox, collapse = ","), " ",
                   remove_slivers)
-    out <- apply_mapshaper_commands(target_layer, cmd, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+    out <- apply_mapshaper_commands(target_layer, cmd, force_FC = force_FC, sys = sys, sys_mem = sys_mem, quiet = quiet)
   } else if (!is.null(overlay_layer)) {
 
     if (sys) {
       on.exit(unlink(c(target_layer, overlay_layer)), add = TRUE)
       cmd <- paste0("-", type)
-      out <- sys_mapshaper(data = target_layer, data2 = overlay_layer, command = cmd, sys_mem = sys_mem)
+      out <- sys_mapshaper(data = target_layer, data2 = overlay_layer, command = cmd, force_FC = force_FC, sys_mem = sys_mem, quiet = quiet)
     } else {
 
       ms <- ms_make_ctx()
@@ -427,7 +394,7 @@ mapshaper_clip_erase <- function(target_layer, overlay_layer, bbox, type,
                         remove_slivers)
 
       if (force_FC) {
-        command <- paste(command, add_dummy_id_command())
+        command <- paste(command, add_dummy_id_command(sys = FALSE))
       }
 
       command <- paste(command, "-o format=geojson")
