@@ -6,7 +6,6 @@
 #' @param input spatial object to dissolve. One of:
 #' \itemize{
 #'  \item \code{geo_json} or \code{character} points or polygons;
-#'  \item \code{geo_list} points or polygons;
 #'  \item \code{SpatialPolygons}, or \code{SpatialPoints}
 #'  }
 #' @param snap Snap together vertices within a small distance threshold to fix
@@ -16,13 +15,13 @@
 #' @param copy_fields fields to copy. The first instance of each field will be
 #'   copied to the aggregated feature.
 #' @param weight Name of an attribute field for generating weighted centroids (points only).
-#' @inheritParams apply_mapshaper_commands
+#' @inheritDotParams apply_mapshaper_commands force_FC sys sys_mem quiet
 #'
 #' @return the same class as the input
 #'
 #' @examples
-#' library(geojsonio)
-#' library(sp)
+#' library(geojsonsf)
+#' library(sf)
 #'
 #' poly <- structure('{"type":"FeatureCollection",
 #'   "features":[
@@ -35,100 +34,85 @@
 #'   "properties":{"a": 5, "b": 3},
 #'   "geometry":{"type":"Polygon","coordinates":[[
 #'   [100,0],[100,1],[101,1],[101,0],[100,0]
-#'   ]]}}]}', class = c("json", "geo_json"))
-#' poly <- geojson_sp(poly)
+#'   ]]}}]}', class = c("geojson", "json"))
+#' poly <- geojson_sf(poly)
 #' plot(poly)
 #' length(poly)
-#' poly@data
+#' poly
 #'
 #' # Dissolve the polygon
 #' out <- ms_dissolve(poly)
 #' plot(out)
 #' length(out)
-#' out@data
+#' out
 #'
 #' # Dissolve and summing columns
 #' out <- ms_dissolve(poly, sum_fields = c("a", "b"))
 #' plot(out)
-#' out@data
+#' out
 #'
 #' @export
 ms_dissolve <- function(input, field = NULL, sum_fields = NULL, copy_fields = NULL,
-                        weight = NULL, snap = TRUE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                        weight = NULL, snap = TRUE, ...) {
   UseMethod("ms_dissolve")
 }
 
 #' @export
 ms_dissolve.character <- function(input, field = NULL, sum_fields = NULL, copy_fields = NULL,
-                                  weight = NULL, snap = TRUE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                  weight = NULL, snap = TRUE, ...) {
   input <- check_character_input(input)
 
   call <- make_dissolve_call(field = field, sum_fields = sum_fields, weight = weight,
                              copy_fields = copy_fields, snap = snap)
 
-  apply_mapshaper_commands(data = input, command = call, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+  apply_mapshaper_commands(data = input, command = call, ...)
 
 }
 
 #' @export
-ms_dissolve.geo_json <- function(input, field = NULL, sum_fields = NULL, copy_fields = NULL,
-                                 weight = NULL, snap = TRUE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
-
+ms_dissolve.json <- function(input, field = NULL, sum_fields = NULL, copy_fields = NULL,
+                                 weight = NULL, snap = TRUE, ...) {
   call <- make_dissolve_call(field = field, sum_fields = sum_fields, weight = weight,
                              copy_fields = copy_fields, snap = snap)
 
-  apply_mapshaper_commands(data = input, command = call, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
-}
-
-#' @export
-ms_dissolve.geo_list <- function(input, field = NULL, sum_fields = NULL, copy_fields = NULL,
-                                 weight = NULL, snap = TRUE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
-
-  call <- make_dissolve_call(field = field, sum_fields = sum_fields, weight = weight,
-                             copy_fields = copy_fields, snap = snap)
-
-  geojson <- geo_list_to_json(input)
-
-  ret <- apply_mapshaper_commands(data = geojson, command = call, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
-
-  geojsonio::geojson_list(ret)
+  apply_mapshaper_commands(data = input, command = call, ...)
 }
 
 #' @export
 ms_dissolve.SpatialPolygons <- function(input, field = NULL, sum_fields = NULL, copy_fields = NULL,
-                                        weight = NULL, snap = TRUE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                        weight = NULL, snap = TRUE, ...) {
  dissolve_sp(input = input, field = field, sum_fields = sum_fields, copy_fields = copy_fields,
-             weight = weight, snap = snap, sys = sys, sys_mem = sys_mem)
+             weight = weight, snap = snap, ...)
 }
 
 #' @export
 ms_dissolve.SpatialPoints <- function(input, field = NULL, sum_fields = NULL, copy_fields = NULL,
-                                      weight = NULL, snap = TRUE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                      weight = NULL, snap = TRUE, ...) {
   dissolve_sp(input = input, field = field, sum_fields = sum_fields, copy_fields = copy_fields,
-              weight = weight, snap = snap, sys = sys, sys_mem = sys_mem)
+              weight = weight, snap = snap, ...)
 }
 
 #' @export
 ms_dissolve.sf <- function(input, field = NULL, sum_fields = NULL, copy_fields = NULL,
-                           weight = NULL, snap = TRUE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                           weight = NULL, snap = TRUE, ...) {
   if (!is.null(weight) && !(weight %in% names(input))) {
     stop("specified 'weight' column not present in input data", call. = FALSE)
   }
 
   dissolve_sf(input = input, field = field, sum_fields = sum_fields, copy_fields = copy_fields,
-              weight = weight, snap = snap, sys = sys, sys_mem = sys_mem)
+              weight = weight, snap = snap, ...)
 
 }
 
 #' @export
 ms_dissolve.sfc <- function(input, field = NULL, sum_fields = NULL, copy_fields = NULL,
-                            weight = NULL, snap = TRUE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                            weight = NULL, snap = TRUE, ...) {
   if (!is.null(weight)) {
     warning("'weight' cannot be used with sfc objects. Ignoring it and proceeding...")
   }
 
   dissolve_sf(input = input, field = field, sum_fields = sum_fields, copy_fields = copy_fields,
-              weight = NULL, snap = snap, sys = sys, sys_mem = sys_mem)
+              weight = NULL, snap = snap, ...)
 }
 
 make_dissolve_call <- function(field, sum_fields, copy_fields, weight, snap) {
@@ -158,7 +142,7 @@ make_dissolve_call <- function(field, sum_fields, copy_fields, weight, snap) {
   call
 }
 
-dissolve_sp <- function(input, field, sum_fields, copy_fields, weight, snap, sys, sys_mem) {
+dissolve_sp <- function(input, field, sum_fields, copy_fields, weight, snap, ...) {
 
   if (!inherits(input, "SpatialPointsDataFrame") && !is.null(weight)) {
     stop("weight arguments only applies to points with attributes", call. = FALSE)
@@ -171,10 +155,10 @@ dissolve_sp <- function(input, field, sum_fields, copy_fields, weight, snap, sys
   call <- make_dissolve_call(field = field, sum_fields = sum_fields, copy_fields = copy_fields,
                              weight = weight, snap = snap)
 
-  ms_sp(input = input, call = call, sys = sys, sys_mem = sys_mem)
+  ms_sp(input = input, call = call, ...)
 }
 
-dissolve_sf <- function(input, field, sum_fields, copy_fields, weight, snap, sys, sys_mem) {
+dissolve_sf <- function(input, field, sum_fields, copy_fields, weight, snap, ...) {
 
   if (!all(sf::st_is(input, c("POINT", "MULTIPOINT", "POLYGON", "MULTIPOLYGON")))) {
     stop("ms_dissolve only works with (MULTI)POINT or (MULTI)POLYGON", call. = FALSE)
@@ -187,5 +171,5 @@ dissolve_sf <- function(input, field, sum_fields, copy_fields, weight, snap, sys
   call <- make_dissolve_call(field = field, sum_fields = sum_fields, copy_fields = copy_fields,
                              weight = weight, snap = snap)
 
-  ms_sf(input = input, call = call, sys = sys, sys_mem = sys_mem)
+  ms_sf(input = input, call = call, ...)
 }
