@@ -5,83 +5,71 @@
 #' @param input spatial object to filter fields on. One of:
 #' \itemize{
 #'  \item \code{geo_json} or \code{character} points, lines, or polygons;
-#'  \item \code{geo_list} points, lines, or polygons;
 #'  \item \code{SpatialPolygonsDataFrame}, \code{SpatialLinesDataFrame}, \code{SpatialPointsDataFrame};
 #'  \item \code{sf} object
 #'  }
 #' @param fields character vector of fields to retain.
-#' @inheritParams apply_mapshaper_commands
+#' @inheritDotParams apply_mapshaper_commands sys sys_mem quiet
 #'
 #' @return object with only specified attributes retained, in the same class as
 #'   the input
 #'
 #' @examples
-#' library(geojsonio)
-#' library(sp)
+#' library(geojsonsf)
+#' library(sf)
 #'
 #' poly <- structure("{\"type\":\"FeatureCollection\",
 #'                   \"features\":[{\"type\":\"Feature\",
 #'                   \"properties\":{\"a\": 1, \"b\":2, \"c\": 3},
 #'                   \"geometry\":{\"type\":\"Polygon\",
 #'                   \"coordinates\":[[[102,2],[102,4],[104,4],[104,2],[102,2]]]}}]}",
-#'                   class = c("json", "geo_json"))
-#' poly <- geojson_sp(poly)
-#' poly@data
+#'                   class = c("geojson", "json"))
+#' poly <- geojson_sf(poly)
+#' poly
 #'
 #' # Filter (keep) fields a and b, drop c
 #' out <- ms_filter_fields(poly, c("a", "b"))
-#' out@data
+#' out
 #'
 #' @export
-ms_filter_fields <- function(input, fields, sys = FALSE, sys_mem = 8) {
+ms_filter_fields <- function(input, fields, ...) {
   if (!is.character(fields)) stop("fields must be a character vector")
   UseMethod("ms_filter_fields")
 }
 
 #' @export
-ms_filter_fields.character <- function(input, fields, sys = FALSE, sys_mem = 8) {
+ms_filter_fields.character <- function(input, fields, ...) {
   input <- check_character_input(input)
 
   cmd <- make_filterfields_call(fields)
 
-  apply_mapshaper_commands(data = input, command = cmd, force_FC = FALSE, sys = sys, sys_mem = sys_mem)
+  apply_mapshaper_commands(data = input, command = cmd, force_FC = FALSE, ...)
 }
 
 #' @export
-ms_filter_fields.geo_json <- function(input, fields, sys = FALSE, sys_mem = 8) {
+ms_filter_fields.json <- function(input, fields, ...) {
   cmd <- make_filterfields_call(fields)
 
-  apply_mapshaper_commands(data = input, command = cmd, force_FC = FALSE, sys = sys, sys_mem = sys_mem)
+  apply_mapshaper_commands(data = input, command = cmd, force_FC = FALSE, ...)
 }
 
 #' @export
-ms_filter_fields.geo_list <- function(input, fields, sys = FALSE, sys_mem = 8) {
-  geojson <- geo_list_to_json(input)
-
-  cmd <- make_filterfields_call(fields)
-
-  ret <- apply_mapshaper_commands(data = geojson, command = cmd, force_FC = FALSE, sys = sys, sys_mem = sys_mem)
-
-  geojsonio::geojson_list(ret)
+ms_filter_fields.SpatialPolygonsDataFrame <- function(input, fields, ...) {
+  ms_filter_fields_sp(input, fields, ...)
 }
 
 #' @export
-ms_filter_fields.SpatialPolygonsDataFrame <- function(input, fields, sys = FALSE, sys_mem = 8) {
-  ms_filter_fields_sp(input, fields, sys = sys, sys_mem = sys_mem)
+ms_filter_fields.SpatialPointsDataFrame <- function(input, fields, ...) {
+  ms_filter_fields_sp(input, fields, ...)
 }
 
 #' @export
-ms_filter_fields.SpatialPointsDataFrame <- function(input, fields, sys = FALSE, sys_mem = 8) {
-  ms_filter_fields_sp(input, fields, sys = sys, sys_mem = sys_mem)
+ms_filter_fields.SpatialLinesDataFrame <- function(input, fields, ...) {
+  ms_filter_fields_sp(input, fields, ...)
 }
 
 #' @export
-ms_filter_fields.SpatialLinesDataFrame <- function(input, fields, sys = FALSE, sys_mem = 8) {
-  ms_filter_fields_sp(input, fields, sys = sys, sys_mem = sys_mem)
-}
-
-#' @export
-ms_filter_fields.sf <- function(input, fields, sys = FALSE, sys_mem = 8) {
+ms_filter_fields.sf <- function(input, fields, ...) {
   if (!all(fields %in% names(input))) {
     stop("Not all fields are in input")
   }
@@ -93,7 +81,7 @@ ms_filter_fields.sf <- function(input, fields, sys = FALSE, sys_mem = 8) {
   input[, fields, drop = FALSE]
 }
 
-ms_filter_fields_sp <- function(input, fields, sys, sys_mem) {
+ms_filter_fields_sp <- function(input, fields, ...) {
 
   # cmd <- make_filterfields_call(fields)
   #
@@ -107,7 +95,7 @@ ms_filter_fields_sp <- function(input, fields, sys, sys_mem) {
     stop("Not all named fields exist in input data", call. = FALSE)
   }
 
-  input@data <- input@data[, fields]
+  input@data <- input@data[, fields, drop = FALSE]
 
   input
 
