@@ -6,7 +6,6 @@
 #' @param input spatial object to filter. One of:
 #' \itemize{
 #'  \item \code{geo_json} or \code{character} polygons;
-#'  \item \code{geo_list} polygons;
 #'  \item \code{SpatialPolygons*};
 #'  \item \code{sf} or \code{sfc} polygons object
 #'  }
@@ -17,14 +16,14 @@
 #' @param drop_null_geometries should features with empty geometries be dropped?
 #'   Default \code{TRUE}. Ignored for \code{SpatialPolyons*}, as it is always
 #'   \code{TRUE}.
-#' @inheritParams apply_mapshaper_commands
+#' @inheritDotParams apply_mapshaper_commands force_FC sys sys_mem quiet
 #'
 #' @return object with only specified features retained, in the same class as
 #'   the input
 #'
 #' @examples
-#' library(geojsonio)
-#' library(sp)
+#' library(geojsonsf)
+#' library(sf)
 #'
 #' poly <- structure("{\"type\":\"FeatureCollection\",
 #'            \"features\":[{\"type\":\"Feature\",\"properties\":{},
@@ -36,9 +35,9 @@
 #'            {\"type\":\"Feature\",\"properties\":{},
 #'            \"geometry\":{\"type\":\"Polygon\",
 #'            \"coordinates\":[[[100,0],[100,1],[101,1],[101,0],[100,0]]]}}]}",
-#'            class = c("json", "geo_json"))
+#'            class = c("geojson", "json"))
 #'
-#' poly <- geojson_sp(poly)
+#' poly <- geojson_sf(poly)
 #' plot(poly)
 #'
 #' out <- ms_filter_islands(poly, min_area = 12391399903)
@@ -46,69 +45,55 @@
 #'
 #' @export
 ms_filter_islands <- function(input, min_area = NULL, min_vertices = NULL, drop_null_geometries = TRUE,
-                              force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                              ...) {
   if (!is.null(min_area) && !is.numeric(min_area)) stop("min_area must be numeric")
   if (!is.null(min_vertices) && !is.numeric(min_vertices)) stop("min_vertices must be numeric")
   if (!is.logical(drop_null_geometries)) stop("drop_null_geometries must be TRUE or FALSE")
-  if (!is.logical(force_FC)) stop("force_FC must be TRUE or FALSE")
   UseMethod("ms_filter_islands")
 }
 
 #' @export
 ms_filter_islands.character <- function(input, min_area = NULL, min_vertices = NULL, drop_null_geometries = TRUE,
-                                        force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                        ...) {
   input <- check_character_input(input)
 
   cmd <- make_filterislands_call(min_area = min_area, min_vertices = min_vertices,
                                  drop_null_geometries = drop_null_geometries)
 
-  apply_mapshaper_commands(data = input, command = cmd, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
+  apply_mapshaper_commands(data = input, command = cmd, ...)
 
 }
 
 #' @export
-ms_filter_islands.geo_json <- function(input, min_area = NULL, min_vertices = NULL, drop_null_geometries = TRUE,
-                                       force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+ms_filter_islands.json <- function(input, min_area = NULL, min_vertices = NULL, drop_null_geometries = TRUE,
+                                       ...) {
   cmd <- make_filterislands_call(min_area = min_area, min_vertices = min_vertices,
                                  drop_null_geometries = drop_null_geometries)
 
-  apply_mapshaper_commands(data = input, command = cmd, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
-}
-
-#' @export
-ms_filter_islands.geo_list <- function(input, min_area = NULL, min_vertices = NULL, drop_null_geometries = TRUE,
-                                       force_FC = TRUE, sys = FALSE, sys_mem = 8) {
-  geojson <- geo_list_to_json(input)
-
-  cmd <- make_filterislands_call(min_area = min_area, min_vertices = min_vertices,
-                                 drop_null_geometries = drop_null_geometries)
-
-  ret <- apply_mapshaper_commands(data = geojson, command = cmd, force_FC = force_FC, sys = sys, sys_mem = sys_mem)
-
-  geojsonio::geojson_list(ret)
+  apply_mapshaper_commands(data = input, command = cmd, ...)
 }
 
 #' @export
 ms_filter_islands.SpatialPolygons <- function(input, min_area = NULL, min_vertices = NULL, drop_null_geometries = TRUE,
-                                              force_FC = TRUE, sys = FALSE, sys_mem = 8) {
-  ms_filter_islands_sp(input, min_area = min_area, min_vertices = min_vertices, sys = sys, sys_mem = sys_mem)
+                                              ...) {
+  ms_filter_islands_sp(input, min_area = min_area, min_vertices = min_vertices, ...)
 }
 
 
-ms_filter_islands_sp <- function(input, min_area = NULL, min_vertices = NULL, sys, sys_mem) {
+ms_filter_islands_sp <- function(input, min_area = NULL, min_vertices = NULL, ...) {
 
   cmd <- make_filterislands_call(min_area = min_area, min_vertices = min_vertices,
                                  drop_null_geometries = TRUE)
-  ms_sp(input = input, call = cmd, sys = sys, sys_mem = sys_mem)
+  ms_sp(input = input, call = cmd, ...)
 }
 
 #' @export
 ms_filter_islands.sf <- function(input, min_area = NULL, min_vertices = NULL,
-                                 drop_null_geometries = TRUE, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+                                 drop_null_geometries = TRUE, ...) {
 
   cmd <- make_filterislands_call(min_area = min_area, min_vertices = min_vertices,
                                  drop_null_geometries = TRUE)
-  ms_sf(input = input, call = cmd, sys = sys, sys_mem = sys_mem)
+  ms_sf(input = input, call = cmd, ...)
 }
 
 #' @export
