@@ -4,7 +4,6 @@
 #' @param input input polygons object to convert to inner lines. One of:
 #' \itemize{
 #'  \item \code{geo_json} or \code{character} polygons;
-#'  \item \code{geo_list} polygons;
 #'  \item \code{SpatialPolygons*};
 #'  \item \code{sf} or \code{sfc} polygons object
 #'  }
@@ -14,14 +13,14 @@
 #'   intermediate level of hierarchy at TYPE 1, with the lowest-level internal
 #'   boundaries set to TYPE 2. Supplying a character vector of field names adds
 #'   additional levels of hierarchy.
-#' @inheritParams apply_mapshaper_commands
+#' @inheritDotParams apply_mapshaper_commands force_FC sys sys_mem quiet
 #'
 #' @return topological boundaries as lines, in the same class as the input
 #'
 #' @examples
 #'
-#' library(geojsonio)
-#' library(sp)
+#' library(geojsonsf)
+#' library(sf)
 #'
 #' poly <- structure('{"type":"FeatureCollection",
 #'              "features":[
@@ -39,9 +38,9 @@
 #'              "properties":{"foo": "b"},
 #'              "geometry":{"type":"Polygon","coordinates":[[
 #'              [102.5,1],[102.5,2],[103.5,2],[103.5,1],[102.5,1]
-#'              ]]}}]}', class = c("json", "geo_json"))
+#'              ]]}}]}', class = c("geojson", "json"))
 #'
-#' poly <- geojson_sp(poly)
+#' poly <- geojson_sf(poly)
 #' summary(poly)
 #' plot(poly)
 #'
@@ -50,45 +49,30 @@
 #' plot(out)
 #'
 #' @export
-ms_lines <- function(input, fields = NULL, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+ms_lines <- function(input, fields = NULL, ...) {
   if (!is.null(fields) && !is.character(fields)) stop("fields must be a character vector of field names")
-  if (!is.logical(force_FC)) stop("force_FC must be TRUE or FALSE")
   UseMethod("ms_lines")
 }
 
 #' @export
-ms_lines.character <- function(input, fields = NULL, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+ms_lines.character <- function(input, fields = NULL, ...) {
   input <- check_character_input(input)
 
   command <- make_lines_call(fields)
 
-  apply_mapshaper_commands(data = input, command = command, force_FC = force_FC,
-                           sys = sys, sys_mem = sys_mem)
+  apply_mapshaper_commands(data = input, command = command, ...)
 
 }
 
 #' @export
-ms_lines.geo_json <- function(input, fields = NULL, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
+ms_lines.json <- function(input, fields = NULL, ...) {
   command <- make_lines_call(fields)
 
-  apply_mapshaper_commands(data = input, command = command, force_FC = force_FC,
-                           sys = sys, sys_mem = sys_mem)
+  apply_mapshaper_commands(data = input, command = command, ...)
 }
 
 #' @export
-ms_lines.geo_list <- function(input, fields = NULL, force_FC = TRUE, sys = FALSE, sys_mem = 8) {
-  geojson <- geo_list_to_json(input)
-
-  command <- make_lines_call(fields)
-
-  ret <- apply_mapshaper_commands(data = geojson, command = command,
-                                  force_FC = force_FC, sys = sys, sys_mem = sys_mem)
-
-  geojsonio::geojson_list(ret)
-}
-
-#' @export
-ms_lines.SpatialPolygons <- function(input, fields = NULL, force_FC, sys = FALSE, sys_mem = 8) {
+ms_lines.SpatialPolygons <- function(input, fields = NULL, ...) {
 
   if (.hasSlot(input, "data")) {
     if (!all(fields %in% names(input@data))) {
@@ -98,37 +82,37 @@ ms_lines.SpatialPolygons <- function(input, fields = NULL, force_FC, sys = FALSE
 
   command <- make_lines_call(fields)
 
-  ms_sp(input, command, sys = sys, sys_mem = sys_mem)
+  ms_sp(input, command, ...)
 }
 
 #' @export
-ms_lines.sf <- function(input, fields = NULL, force_FC, sys = FALSE, sys_mem = 8) {
+ms_lines.sf <- function(input, fields = NULL, ...) {
 
   if (!all(fields %in% names(input))) {
     stop("not all fields specified exist in input data")
   }
 
-  lines_sf(input = input, fields = fields, sys = sys, sys_mem = sys_mem)
+  lines_sf(input = input, fields = fields, ...)
 }
 
 #' @export
-ms_lines.sfc <- function(input, fields = NULL, force_FC, sys = FALSE, sys_mem = 8) {
+ms_lines.sfc <- function(input, fields = NULL, ...) {
 
   if (!is.null(fields)) {
     stop("Do not specify fields for sfc classes", call. = FALSE)
   }
 
-  lines_sf(input = input, fields = fields, sys = sys, sys_mem = sys_mem)
+  lines_sf(input = input, fields = fields, ...)
 }
 
-lines_sf <- function(input, fields, sys, sys_mem) {
+lines_sf <- function(input, fields, ...) {
   if (!all(sf::st_is(input, c("POLYGON", "MULTIPOLYGON")))) {
     stop("ms_lines only works with (MULTI)POLYGON")
   }
 
   command <- make_lines_call(fields)
 
-  ms_sf(input, command, sys = sys, sys_mem = sys_mem)
+  ms_sf(input, command, ...)
 }
 
 make_lines_call <- function(fields) {
